@@ -1,11 +1,14 @@
-import collections
+try:
+    from collections.abc import Mapping
+except ImportError:
+    from collections import Mapping
 
 from .settings import preferences_settings
 from .exceptions import CachedValueNotFound, DoesNotExist
 from .signals import preference_updated
 
 
-class PreferencesManager(collections.Mapping):
+class PreferencesManager(Mapping):
 
     """Handle retrieving / caching of preferences"""
 
@@ -106,7 +109,7 @@ class PreferencesManager(collections.Mapping):
             # resulting in more DB queries, so we cache an arbitrary value
             # to ensure the cache is hot (even with empty values)
             value = preferences_settings.CACHE_NONE_VALUE
-        self.cache.set(key, value, None)
+        self.cache.set(key, value)
 
     def pref_obj(self, section, name):
         return self.registry.get(section=section, name=name)
