@@ -230,8 +230,12 @@ class ModelMultipleSerializer(ModelSerializer):
     def to_db(self, value, **kwargs):
         if not value:
             return
-
-        value = list(value.values_list('pk', flat=True))
+        if hasattr(value, "pk"):
+            # Support single instances in this serializer to allow
+            # create_deletion_handler to work for model multiple choice preferences
+            value = [value.pk]
+        else:
+            value = list(value.values_list('pk', flat=True))
 
         if self.sort:
             value = sorted(value)
@@ -242,8 +246,12 @@ class ModelMultipleSerializer(ModelSerializer):
         if value in EMPTY_VALUES:
             return self.model.objects.none()
 
-        pks = value.split(",")
-        return self.model.objects.filter(pk__in=pks)
+        try:
+            pks = value.split(",")
+            pks = [int(i) for i in pks]
+            return self.model.objects.filter(pk__in=pks)    
+        except:
+            raise self.exception("Array {0} cannot be converted to int".format(value))
 
 
 class PreferenceFieldFile(FieldFile):
@@ -275,6 +283,7 @@ class PreferenceFieldFile(FieldFile):
             and delete files, so we are effectively mocking that.
             """
             name = 'noop'
+            attname = 'noop'
             max_length = 10000
 
             def generate_filename(field, instance, name):
