@@ -336,6 +336,8 @@ class ModelChoicePreference(BasePreferenceType):
     def api_repr(self, value):
         if not value:
             return None
+        if value.__class__.__name__=='QuerySet':
+            return [val.pk for val in value]
         return value.pk
 
 
@@ -369,6 +371,9 @@ class ModelMultipleChoicePreference(ModelChoicePreference):
     serializer_class = ModelMultipleSerializer
     field_class = forms.ModelMultipleChoiceField
 
+    def _setup_signals(self):
+        pass
+
 
 class FilePreference(BasePreferenceType):
     """
